# PII Change Audit Report
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/pii-change-audit-report#overview)
  * [Report Content](https://help.sap.com/docs/leanix/ea/pii-change-audit-report#report-content)
  * [Exporting PII Change Data](https://help.sap.com/docs/leanix/ea/pii-change-audit-report#exporting-pii-change-data)
  * [Result](https://help.sap.com/docs/leanix/ea/pii-change-audit-report#result)


Export a record of changes to the personally identifiable information (PII) of individual users. Workspace administrators use this report to meet compliance and audit requirements.
